WakewordAudioOption enum

iOS audio session category options used by wake-word audio routing.

Inheritance
Available extensions

Values

mixWithOthers → const WakewordAudioOption

AVAudioSession.CategoryOptions.mixWithOthers.

duckOthers → const WakewordAudioOption

AVAudioSession.CategoryOptions.duckOthers.

allowBluetooth → const WakewordAudioOption

AVAudioSession.CategoryOptions.allowBluetooth.

allowBluetoothA2DP → const WakewordAudioOption

AVAudioSession.CategoryOptions.allowBluetoothA2DP.

allowAirPlay → const WakewordAudioOption

AVAudioSession.CategoryOptions.allowAirPlay.

defaultToSpeaker → const WakewordAudioOption

AVAudioSession.CategoryOptions.defaultToSpeaker.

overrideMutedMicrophoneInterruption → const WakewordAudioOption

AVAudioSession.CategoryOptions.overrideMutedMicrophoneInterruption.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonValue() String
Returns the native JSON string value.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<WakewordAudioOption>
A constant List of the values in this enum, in order of their declaration.