WakewordPreferredInput enum
Preferred input selection for wake-word audio routing.
Values
- none → const WakewordPreferredInput
-
Do not force a preferred input.
- builtInMic → const WakewordPreferredInput
-
Prefer the built-in phone microphone.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJsonValue(
) → String - Returns the native JSON string value.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
WakewordPreferredInput> - A constant List of the values in this enum, in order of their declaration.