SpeakerVerificationRNBridgeInstance class

Flutter equivalent of the React Native SpeakerVerificationRNBridgeInstance.

Constructors

SpeakerVerificationRNBridgeInstance(String engineId)
Creates a speaker verification engine handle.

Properties

engineId String
Native engine identifier.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(String modelPathOrName, String enrollmentJsonPathOrName, {Map<String, dynamic> options = const <String, dynamic>{}}) Future
Creates the native speaker verifier engine.
destroy() Future<void>
Destroys the native speaker verifier engine.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
verifyWavStreaming(String wavPathOrName, {bool resetState = true}) Future<Map<String, dynamic>>
Verifies a WAV file by streaming it through the native engine.

Operators

operator ==(Object other) bool
The equality operator.
inherited