AudioRoutingConfig class

Full wake-word audio routing configuration.

Constructors

AudioRoutingConfig({required RouteConfigEntry defaultRoute, RouteConfigEntry? carAudio, RouteConfigEntry? builtInReceiver, RouteConfigEntry? builtInSpeaker, RouteConfigEntry? bluetoothA2DP, RouteConfigEntry? bluetoothHFP, RouteConfigEntry? headphones})
Creates an audio routing configuration.
const

Properties

bluetoothA2DP RouteConfigEntry?
Bluetooth A2DP output route config.
final
bluetoothHFP RouteConfigEntry?
Bluetooth HFP output route config.
final
builtInReceiver RouteConfigEntry?
Built-in receiver output route config.
final
builtInSpeaker RouteConfigEntry?
Built-in speaker output route config.
final
carAudio RouteConfigEntry?
CarPlay/car audio output route config.
final
defaultRoute RouteConfigEntry
Default route config.
final
hashCode int
The hash code for this object.
no setterinherited
headphones RouteConfigEntry?
Headphones output route config.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this config to the JSON-compatible map expected by native iOS.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited