RouteConfigEntry class
A per-route audio routing entry for iOS wake-word detection.
Constructors
-
RouteConfigEntry({required WakewordAudioCategory category, required WakewordAudioMode mode, required List<
WakewordAudioOption> options, required WakewordPreferredInput preferredInput}) -
Creates an audio routing entry.
const
Properties
- category → WakewordAudioCategory
-
Audio session category.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mode → WakewordAudioMode
-
Audio session mode.
final
-
options
→ List<
WakewordAudioOption> -
Audio session category options.
final
- preferredInput → WakewordPreferredInput
-
Preferred input.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this entry to the JSON-compatible map expected by native iOS.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited