SpeakerVerificationMicController class
Flutter equivalent of the React Native SpeakerVerificationMicController.
Constructors
- SpeakerVerificationMicController(String controllerId)
- Creates a speaker verification mic controller handle.
Properties
- controllerId → String
-
Native controller identifier.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
beginOnboarding(
String enrollmentId, int targetEmbeddingCount, {bool reset = true}) → Future - Starts speaker onboarding.
-
create(
dynamic configJson) → Future - Creates the native mic controller.
-
destroy(
) → Future - Destroys the native mic controller.
-
finalizeOnboardingNow(
) → Future - Finalizes onboarding immediately.
-
getNextEmbeddingFromMic(
) → Future - Captures the next enrollment embedding from the microphone.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setEnrollmentJson(
dynamic enrollmentJson) → Future - Sets enrollment JSON used for verification.
-
startEndlessVerifyFromMic(
{double hopSeconds = 0.5, bool stopOnMatch = false, bool resetState = true}) → Future - Starts endless microphone verification.
-
startVerifyFromMic(
{bool resetState = true}) → Future - Starts one microphone verification pass.
-
stop(
) → Future - Stops microphone verification/onboarding.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited